CREATE PROCEDURE [dbo].[Custom_ExportDataForDTUCalculator]
  @DeviceID     smallint,
  @BeginTime    datetime = NULL, -- local time
  @EndTime      datetime = NULL  -- local time
AS
BEGIN
  SET NOCOUNT ON; 

  DECLARE @offset int = DATEDIFF(second, GETDATE(), GETUTCDATE());

  -- Convert local time to UTC time
  DECLARE @BeginUTCTime datetime = DATEADD(second, @offset, @BeginTime),
          @EndUTCTime   datetime = DATEADD(second, @offset, @EndTime);

  SELECT 
    CONVERT(VARCHAR(8),[TimeStamp],112) + ' ' 
	   + LTRIM(RIGHT(CONVERT(CHAR(20), [TimeStamp], 22), 11)) as [Interval],
    [% Processor Time],
    [Disk Reads/sec],
    [Disk Writes/sec],
    [Log Bytes Flushed/sec]
  FROM
  (
    SELECT [TimeStamp],
	       [Disk Reads/sec],
		   [Disk Writes/sec],
		   [Log Bytes Flushed/sec],
		   [% Processor Time]
    FROM 
	(     
	  SELECT [TimeStamp], CounterName, [Value]
		FROM dbo.AzureDatabaseDTUdata
		WHERE InstanceName = N'_Total'
		AND DeviceID = @DeviceID
		AND [TimeStamp] >= COALESCE(@BeginUTCTime, '19000101')
		AND [Timestamp] <= COALESCE(@EndUTCTime,   '20991231')
    ) D
    PIVOT (MAX([Value]) FOR [CounterName] in 
    (
	  [Disk Reads/sec],
	  [Disk Writes/sec],
	  [Log Bytes Flushed/sec],
	  [% Processor Time])
	) AS pvt
  ) A
  ORDER BY [TimeStamp] DESC;
END
GO